@@ -1,6 +1,11 @@
 package MooseX::LazyRequire::Meta::Attribute::Trait::LazyRequire;
-our $VERSION = '0.03';
-
+BEGIN {
+  $MooseX::LazyRequire::Meta::Attribute::Trait::LazyRequire::AUTHORITY = 'cpan:FLORA';
+}
+BEGIN {
+  $MooseX::LazyRequire::Meta::Attribute::Trait::LazyRequire::VERSION = '0.05';
+}
+# ABSTRACT: Attribute trait to make getters fail on unset attributes
 
 use Moose::Role;
 use Carp qw/cluck/;
@@ -38,22 +43,23 @@ after _process_options => sub {
 
 package # hide
     Moose::Meta::Attribute::Custom::Trait::LazyRequire;
+BEGIN {
+  $Moose::Meta::Attribute::Custom::Trait::LazyRequire::AUTHORITY = 'cpan:FLORA';
+}
+BEGIN {
+  $Moose::Meta::Attribute::Custom::Trait::LazyRequire::VERSION = '0.05';
+}
 
 sub register_implementation { 'MooseX::LazyRequire::Meta::Attribute::Trait::LazyRequire' }
 
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
 
-MooseX::LazyRequire::Meta::Attribute::Trait::LazyRequire
-
-=head1 VERSION
-
-version 0.03
+MooseX::LazyRequire::Meta::Attribute::Trait::LazyRequire - Attribute trait to make getters fail on unset attributes
 
 =head1 AUTHOR
 
@@ -61,11 +67,10 @@ version 0.03
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Florian Ragwitz.
+This software is copyright (c) 2010 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
